package Qt::Core::QLibraryInfo;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QLibraryInfo
# file     : QtCore/qlibraryinfo.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';


# FIXME: operator overload


1;

=head1 NAME

Qt::Core::QLibraryInfo

=head1 PUBLIC METHODS

=over

=item  static QDate buildDate()

=item  static QString buildKey()

=item  static QString licensedProducts()

=item  static QString licensee()

=item  static QString location(QLibraryInfo::LibraryLocation arg0)


=back

=head1 ENUM VALUES

=over

=item PrefixPath

=item DocumentationPath

=item HeadersPath

=item LibrariesPath

=item BinariesPath

=item PluginsPath

=item DataPath

=item TranslationsPath

=item SettingsPath

=item DemosPath

=item ExamplesPath

=item ImportsPath


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
